require 'spec_helper'
require 'matrix'

describe Samscript::WaitMatcher do
  before :all do
    java_import 'java.awt.Point'
    java_import 'java.awt.Color'
  end

  it "wait for pixel base" do
    location  = [100, 100]
    colour    = Color.new(100, 100, 100)
    match     = :any
    tolerance = 0
    interval  = 50
    timeout   = 3000

    args = { location: location,
             colour: colour,
             match: match,
             tolerance: tolerance,
             interval: interval,
             timeout: timeout }

    lambda {
      Samscript::Screen.wait_for_pixel args
    }.should_not raise_error
  end

  context "validation of wait_for_pixel params" do
    let(:random) { Random.new }

    it "no params" do
      lambda {
        Samscript::WaitMatcher.validate_wait_params({})
      }.should raise_error
    end

    it "locations" do
      x = random.rand(100)
      y = random.rand(100)

      locations = [[x, y], Vector[x, y], Point.new(x, y)]
      labels = [:at, :location, :coords, :point, :pixel]

      locations.each do |location|
        labels.each do |label|
          result = Samscript::WaitMatcher.parse_location(label => location)
          result.should == Vector[x, y]
        end
      end
    end

    it "colours" do
      r = random.rand(255)
      g = random.rand(255)
      b = random.rand(255)

      colours = [[r, g, b], Color.new(r, g, b)]
      labels = [:colour, :color]

      colours.each do |colour|
        labels.each do |label|
          result = Samscript::WaitMatcher.parse_colour(label => colour)
          result.should == Color.new(r, g, b)
        end
      end
    end
  end
end